diff --git a/LICENSES.md b/LICENSES.md
index b6044d3ac4..483a6e4072 100644
--- a/LICENSES.md
+++ b/LICENSES.md
@@ -1,12 +1,12 @@
-# Open MCT Web Licenses
+# Open MCT Licenses
-Open MCT Web, Copyright (c) 2014-2015, United States Government as represented by the Administrator of the National Aeronautics and Space Administration. All rights reserved.
+Open MCT, Copyright (c) 2014-2016, United States Government as represented by the Administrator of the National Aeronautics and Space Administration. All rights reserved.
-Open MCT Web is licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0.
+Open MCT is licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0.
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
-Open MCT Web includes source code licensed under additional open source licenses as follows.
+Open MCT includes source code licensed under additional open source licenses as follows.
## Software Components Licenses
diff --git a/README.md b/README.md
index 8c4713c53b..e2d3a979d9 100644
--- a/README.md
+++ b/README.md
@@ -1,7 +1,67 @@
# Open MCT [![license](https://img.shields.io/badge/license-Apache%202.0-blue.svg)](http://www.apache.org/licenses/LICENSE-2.0)
-Open MCT is a web-based platform for mission operations user interface
-software.
+Open MCT is a next-generation mission control framework for visualization of data on desktop and mobile devices. It is developed at NASA's Ames Research Center, and is being used by NASA for data analysis of spacecraft missions, as well as planning and operation of experimental rover systems. As a generalizable and open source framework, Open MCT could be used as the basis for building applications for planning, operation, and analysis of any systems producing telemetry data.
+
+Please visit our [Official Site](https://nasa.github.io/openmct/) and [Getting Started Guide](https://nasa.github.io/openmct/getting-started/)
+
+## See Open MCT in Action
+
+Try Open MCT now with our [live demo](https://openmct-demo.herokuapp.com/).
+![Demo](https://nasa.github.io/openmct/static/res/images/Open-MCT.Browse.Layout.Mars-Weather-1.jpg)
+
+## Building and Running Open MCT Locally
+
+Building and running Open MCT in your local dev environment is very easy. Be sure you have [Git](https://git-scm.com/downloads) and [Node.js](https://nodejs.org/) installed, then follow the directions below. Need additional information? Check out the [Getting Started](https://nasa.github.io/openmct/getting-started/) page on our website.
+
+1. Clone the source code
+
+ `git clone https://github.com/nasa/openmct.git`
+
+2. Install development dependencies
+
+ `npm install`
+
+3. Run a local development server
+
+ `npm start`
+
+Open MCT is now running, and can be accessed by pointing a web browser at [http://localhost:8080/](http://localhost:8080/)
+
+## Documentation
+
+Documentation is available on the [Open MCT website](https://nasa.github.io/openmct/documentation/). The documentation can also be built locally.
+
+### Building the Open MCT Documentation Locally
+Open MCT's documentation is generated by an
+[npm](https://www.npmjs.com/)-based build. It has additional dependencies that
+may not be available on every platform and thus is not covered in the standard
+npm install. Ensure your system has [libcairo](http://cairographics.org/)
+installed and then run the following commands:
+
+* `npm install`
+* `npm install canvas nomnoml`
+* `npm run docs`
+
+Documentation will be generated in `target/docs`.
+
+## Deploying Open MCT
+
+Open MCT is built using [`npm`](http://npmjs.com/)
+and [`gulp`](http://gulpjs.com/).
+
+To build Open MCT for deployment:
+
+`npm run prepublish`
+
+This will compile and minify JavaScript sources, as well as copy over assets.
+The contents of the `dist` folder will contain a runnable Open MCT
+instance (e.g. by starting an HTTP server in that directory), including:
+
+* A `main.js` file containing Open MCT source code.
+* Various assets in the `example` and `platform` directories.
+* An `index.html` that runs Open MCT in its default configuration.
+
+Additional `gulp` tasks are defined in [the gulpfile](gulpfile.js).
## Bundles
@@ -54,39 +114,6 @@ To run:
* `npm install`
* `npm run all`
-## Build
-
-Open MCT is built using [`npm`](http://npmjs.com/)
-and [`gulp`](http://gulpjs.com/).
-
-To build:
-
-`npm run prepublish`
-
-This will compile and minify JavaScript sources, as well as copy over assets.
-The contents of the `dist` folder will contain a runnable Open MCT
-instance (e.g. by starting an HTTP server in that directory), including:
-
-* A `main.js` file containing Open MCT source code.
-* Various assets in the `example` and `platform` directories.
-* An `index.html` that runs Open MCT in its default configuration.
-
-Additional `gulp` tasks are defined in [the gulpfile](gulpfile.js).
-
-### Building Documentation
-
-Open MCT's documentation is generated by an
-[npm](https://www.npmjs.com/)-based build. It has additional dependencies that
-may not be available on every platform and thus is not covered in the standard
-npm install. Ensure your system has [libcairo](http://cairographics.org/)
-installed and then run the following commands:
-
-* `npm install`
-* `npm install canvas nomnoml`
-* `npm run docs`
-
-Documentation will be generated in `target/docs`.
-
# Glossary
Certain terms are used throughout Open MCT with consistent meanings
diff --git a/app.js b/app.js
index 3c976a735a..6b7b1bb635 100644
--- a/app.js
+++ b/app.js
@@ -42,6 +42,8 @@
process.exit(0);
}
+ app.disable('x-powered-by');
+
// Override bundles.json for HTTP requests
app.use('/' + BUNDLE_FILE, function (req, res) {
var bundles;
diff --git a/build-docs.sh b/build-docs.sh
index 87ada35524..ca7dc97c2e 100755
--- a/build-docs.sh
+++ b/build-docs.sh
@@ -1,11 +1,11 @@
#!/bin/bash
#*****************************************************************************
-#* Open MCT Web, Copyright (c) 2014-2015, United States Government
+#* Open MCT, Copyright (c) 2014-2016, United States Government
#* as represented by the Administrator of the National Aeronautics and Space
#* Administration. All rights reserved.
#*
-#* Open MCT Web is licensed under the Apache License, Version 2.0 (the
+#* Open MCT is licensed under the Apache License, Version 2.0 (the
#* "License"); you may not use this file except in compliance with the License.
#* You may obtain a copy of the License at
#* http://www.apache.org/licenses/LICENSE-2.0.
@@ -16,7 +16,7 @@
#* License for the specific language governing permissions and limitations
#* under the License.
#*
-#* Open MCT Web includes source code licensed under additional open source
+#* Open MCT includes source code licensed under additional open source
#* licenses. See the Open Source Licenses file (LICENSES.md) included with
#* this source code distribution or the Licensing information page available
#* at runtime from the About dialog for additional information.
diff --git a/docs/gendocs.js b/docs/gendocs.js
index 10facc0ded..8d257625d0 100644
--- a/docs/gendocs.js
+++ b/docs/gendocs.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
diff --git a/docs/src/design/planning/APIRefactor.md b/docs/src/design/planning/APIRefactor.md
index 8f693cb814..ec98a115f4 100644
--- a/docs/src/design/planning/APIRefactor.md
+++ b/docs/src/design/planning/APIRefactor.md
@@ -1,7 +1,7 @@
# API Refactoring
This document summarizes a path toward implementing API changes
-from the [API Redesign](../proposals/APIRedesign.md) for Open MCT Web
+from the [API Redesign](../proposals/APIRedesign.md) for Open MCT
v1.0.0.
# Goals
@@ -161,7 +161,7 @@ be included in a straightforward fashion.
Some goals for this build step:
-* Compile (and, preferably, optimize/minify) Open MCT Web
+* Compile (and, preferably, optimize/minify) Open MCT
sources into a single `.js` file.
* It is desirable to do the same for HTML sources, but
may wish to defer this until a subsequent refactoring
@@ -170,7 +170,7 @@ Some goals for this build step:
derivative projects in a straightforward fashion.
Should also consider which dependency/packaging manager should
-be used by dependent projects to obtain Open MCT Web. Approaches
+be used by dependent projects to obtain Open MCT. Approaches
include:
1. Plain `npm`. Dependents then declare their dependency with
@@ -203,7 +203,7 @@ to use for asset generation/management and compilation/minification/etc.
## Step 3. Separate repositories
-Refactor existing applications built on Open MCT Web such that they
+Refactor existing applications built on Open MCT such that they
are no longer forks, but instead separate projects with a dependency
on the built artifacts from Step 2.
@@ -211,7 +211,7 @@ Note that this is achievable already using `bower` (see `warp-bower`
branch at http://developer.nasa.gov/mct/warp for an example.)
However, changes involved in switching to an imperative API and
introducing a build process may change (and should simplify) the
-approach used to utilize Open MCT Web as a dependency, so these
+approach used to utilize Open MCT as a dependency, so these
changes should be introduced first.
## Step 4. Design registration API
@@ -287,7 +287,7 @@ or separately in parallel) and should involve a tight cycle of:
planning should be done to spread out the changes incrementally.
By necessity, these changes may break functionality in applications
-built using Open MCT Web. On a case-by-case basis, should consider
+built using Open MCT. On a case-by-case basis, should consider
providing temporary "legacy support" to allow downstream updates
to occur as a separate task; the relevant trade here is between
waste/effort required to maintain legacy support, versus the
@@ -299,11 +299,11 @@ across several repositories.
Update bundles to remove any usages of legacy support for bundles
(including that used by dependent projects.) Then, remove legacy
-support from Open MCT Web.
+support from Open MCT.
## Step 8. Release candidacy
-Once API changes are complete, Open MCT Web should enter a release
+Once API changes are complete, Open MCT should enter a release
candidacy cycle. Important things to look at here:
* Are changes really complete?
diff --git a/docs/src/design/proposals/APIRedesign.md b/docs/src/design/proposals/APIRedesign.md
index 479460b457..d14f4ce469 100644
--- a/docs/src/design/proposals/APIRedesign.md
+++ b/docs/src/design/proposals/APIRedesign.md
@@ -1,6 +1,6 @@
# Overview
-The purpose of this document is to review feedback on Open MCT Web's
+The purpose of this document is to review feedback on Open MCT's
current API and propose improvements to the API, particularly for a
1.0.0 release.
@@ -64,7 +64,7 @@ useful, powerful interfaces.
## Developer Intern Feedback
This feedback comes from interns who worked closely with
-Open MCT Web as their primary task over the Summer of 2015.
+Open MCT as their primary task over the Summer of 2015.
### Developer Intern 1
@@ -104,7 +104,7 @@ Worked on bug fixes in the platform and a plugin for search.
Worked on platform bug fixes and mobile support.
-* No guide for the UI and front end for the HTML/CSS part of Open MCT Web.
+* No guide for the UI and front end for the HTML/CSS part of Open MCT.
Not sure if this is applicable or needed for developers, however would
be helpful to any front end development
* Found it difficult to follow the plot controller & subplot
@@ -118,11 +118,11 @@ Worked on platform bug fixes and mobile support.
## Plugin Developer Feedback
This feedback comes from developers who have worked on plugins for
-Open MCT Web, but have not worked on the platform.
+Open MCT, but have not worked on the platform.
### Plugin Developer 1
-Used Open MCT Web over the course of several months (on a
+Used Open MCT over the course of several months (on a
less-than-half-time basis) to develop a
spectrum visualization plugin.
@@ -138,7 +138,7 @@ spectrum visualization plugin.
### Plugin Developer 2
-Used Open MCT Web over the course of several weeks (on a half-time basis)
+Used Open MCT over the course of several weeks (on a half-time basis)
to develop a tabular visualization plugin.
* Pain points
@@ -197,7 +197,7 @@ to develop a tabular visualization plugin.
## Long-term Developer Notes
The following notes are from original platform developer, with long
-term experience using Open MCT Web.
+term experience using Open MCT.
* Bundle mechanism allows for grouping related components across concerns,
and adding and removing these easily. (e.g. model and view components of
@@ -220,7 +220,7 @@ or reducing the Angular dependency.
### Angular's Role
-Angular is Open MCT Web's:
+Angular is Open MCT's:
* Dependency injection framework.
* Template rendering.
@@ -268,7 +268,7 @@ by experience:
* Feedback from new developers is that Angular was a hindrance to
training, not a benefit. ("One more thing to learn.") Significant
- documentation remains necessary for Open MCT Web.
+ documentation remains necessary for Open MCT.
* Expected enhancements to maintainability will be effectively
invalidated by an expected Angular end-of-life.
* Data binding and automatic view updates do save development effort,
@@ -526,7 +526,7 @@ subset of `$http`'s functionality.
### Detriments
-* Increases the number of interfaces in Open MCT Web. (Arguably,
+* Increases the number of interfaces in Open MCT. (Arguably,
not really, since the same interfaces would exist if exposed
by Angular.)
@@ -574,7 +574,7 @@ This would also allow for "composite bundles" which serve as
proxies for multiple bundles. The `BundleContext` could contain
(or later be amended to contain) filtering rules to ignore
other bundles and so forth (this has been useful for administering
-Open MCT Web in subtly different configurations in the past.)
+Open MCT in subtly different configurations in the past.)
### Benefits
@@ -827,7 +827,7 @@ This could be resolved by:
## Nomenclature Change
-Instead of presenting Open MCT Web as a "framework" or
+Instead of presenting Open MCT as a "framework" or
"platform", present it as an "extensible application."
This is mostly a change for the developer guide. A
@@ -1040,7 +1040,7 @@ This is a more specific variant of
* Removes a whole category of API (bundle definitions), reducing
learning curve associated with the software.
* Closer to Angular style, reducing disconnect between learning
- Angular and learning Open MCT Web (reducing burden of having
+ Angular and learning Open MCT (reducing burden of having
to learn multiple paradigms.)
* Clarifies "what can be found where" (albeit not perfectly)
since you can look to module dependencies and follow back from there.
diff --git a/example/README.md b/example/README.md
index 0e1b29c036..d6f3afaec0 100644
--- a/example/README.md
+++ b/example/README.md
@@ -1,2 +1,2 @@
This directory is for example bundles, which are intended to illustrate
-how to author new software components using Open MCT Web.
+how to author new software components using Open MCT.
diff --git a/example/builtins/bundle.js b/example/builtins/bundle.js
index 9192a19767..ed37336340 100644
--- a/example/builtins/bundle.js
+++ b/example/builtins/bundle.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
diff --git a/example/builtins/res/templates/example.html b/example/builtins/res/templates/example.html
index e298489fff..3bd7ac347f 100644
--- a/example/builtins/res/templates/example.html
+++ b/example/builtins/res/templates/example.html
@@ -1,9 +1,9 @@
-
-
-
-
-
+
+
- Dirty: {{aForm.$dirty}}
@@ -33,11 +35,8 @@
-
-
-
-
+
\ No newline at end of file
diff --git a/example/forms/src/ExampleFormController.js b/example/forms/src/ExampleFormController.js
index 80d27eebc0..f3f8c95a4e 100644
--- a/example/forms/src/ExampleFormController.js
+++ b/example/forms/src/ExampleFormController.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
@@ -78,27 +78,26 @@ define(
items: [
{
control: "button",
- glyph: "1",
- description: "Button A",
+ csslass: "icon-save",
click: function () {
- window.alert("A");
+ window.alert("Save");
}
},
{
control: "button",
- glyph: "2",
+ csslass: "icon-x",
description: "Button B",
click: function () {
- window.alert("B");
+ window.alert("Cancel");
}
},
{
control: "button",
- glyph: "3",
+ csslass: "icon-trash",
description: "Button C",
disabled: true,
click: function () {
- window.alert("C");
+ window.alert("Delete");
}
}
]
diff --git a/example/generator/bundle.js b/example/generator/bundle.js
index 6e89023ea4..0eadfad5e9 100644
--- a/example/generator/bundle.js
+++ b/example/generator/bundle.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
@@ -86,7 +86,7 @@ define([
{
"key": "generator",
"name": "Sine Wave Generator",
- "glyph": "\u0054",
+ "cssclass": "icon-telemetry",
"description": "For development use. Generates example streaming telemetry data using a simple sine wave algorithm.",
"priority": 10,
"features": "creation",
diff --git a/example/generator/src/SinewaveConstants.js b/example/generator/src/SinewaveConstants.js
index 29136ebb99..f9f48dc0e2 100644
--- a/example/generator/src/SinewaveConstants.js
+++ b/example/generator/src/SinewaveConstants.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
diff --git a/example/generator/src/SinewaveDeltaFormat.js b/example/generator/src/SinewaveDeltaFormat.js
index 19f3e631f9..e85fda2b28 100644
--- a/example/generator/src/SinewaveDeltaFormat.js
+++ b/example/generator/src/SinewaveDeltaFormat.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
diff --git a/example/generator/src/SinewaveLimitCapability.js b/example/generator/src/SinewaveLimitCapability.js
index ac4f4718a2..cac4f3abf0 100644
--- a/example/generator/src/SinewaveLimitCapability.js
+++ b/example/generator/src/SinewaveLimitCapability.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
diff --git a/example/generator/src/SinewaveTelemetryProvider.js b/example/generator/src/SinewaveTelemetryProvider.js
index a50cf4b2cf..4097ebc75d 100644
--- a/example/generator/src/SinewaveTelemetryProvider.js
+++ b/example/generator/src/SinewaveTelemetryProvider.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
diff --git a/example/generator/src/SinewaveTelemetrySeries.js b/example/generator/src/SinewaveTelemetrySeries.js
index 8643b0429b..7ad281d2dd 100644
--- a/example/generator/src/SinewaveTelemetrySeries.js
+++ b/example/generator/src/SinewaveTelemetrySeries.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
diff --git a/example/identity/bundle.js b/example/identity/bundle.js
index 6e1a14a898..7e2c073225 100644
--- a/example/identity/bundle.js
+++ b/example/identity/bundle.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
diff --git a/example/identity/src/ExampleIdentityService.js b/example/identity/src/ExampleIdentityService.js
index 465bc9e0f1..61fac5cb79 100644
--- a/example/identity/src/ExampleIdentityService.js
+++ b/example/identity/src/ExampleIdentityService.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
diff --git a/example/imagery/bundle.js b/example/imagery/bundle.js
index 6e5ac136a9..6232229e40 100644
--- a/example/imagery/bundle.js
+++ b/example/imagery/bundle.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
@@ -49,7 +49,7 @@ define([
{
"key": "imagery",
"name": "Example Imagery",
- "glyph": "\u00e3",
+ "cssclass": "icon-image",
"features": "creation",
"description": "For development use. Creates example imagery data that mimics a live imagery stream.",
"priority": 10,
diff --git a/example/imagery/src/ImageTelemetry.js b/example/imagery/src/ImageTelemetry.js
index 127b65deba..b184f90c4e 100644
--- a/example/imagery/src/ImageTelemetry.js
+++ b/example/imagery/src/ImageTelemetry.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
diff --git a/example/imagery/src/ImageTelemetryProvider.js b/example/imagery/src/ImageTelemetryProvider.js
index f541c441a4..b0e9f4a8f6 100644
--- a/example/imagery/src/ImageTelemetryProvider.js
+++ b/example/imagery/src/ImageTelemetryProvider.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
diff --git a/example/mobile/bundle.js b/example/mobile/bundle.js
index f7c37e8d72..73487da364 100644
--- a/example/mobile/bundle.js
+++ b/example/mobile/bundle.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
diff --git a/example/mobile/res/sass/mobile-example.scss b/example/mobile/res/sass/mobile-example.scss
index 41071c5061..99c14d305b 100644
--- a/example/mobile/res/sass/mobile-example.scss
+++ b/example/mobile/res/sass/mobile-example.scss
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
@@ -25,7 +25,7 @@
@include phoneandtablet {
// Show the Create button
- .create-btn-holder {
+ .create-button-holder {
display: block !important;
}
}
diff --git a/example/msl/bundle.js b/example/msl/bundle.js
index 132878e296..aefc3ffc16 100644
--- a/example/msl/bundle.js
+++ b/example/msl/bundle.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
@@ -43,18 +43,18 @@ define([
{
"name":"Mars Science Laboratory",
"key": "msl.curiosity",
- "glyph": "o"
+ "cssclass": "icon-object"
},
{
"name": "Instrument",
"key": "msl.instrument",
- "glyph": "o",
+ "cssclass": "icon-object",
"model": {"composition": []}
},
{
"name": "Measurement",
"key": "msl.measurement",
- "glyph": "\u0054",
+ "cssclass": "icon-telemetry",
"model": {"telemetry": {}},
"telemetry": {
"source": "rems.source",
diff --git a/example/msl/src/MSLDataDictionary.js b/example/msl/src/MSLDataDictionary.js
index 129e1fba59..671b6fcb7d 100644
--- a/example/msl/src/MSLDataDictionary.js
+++ b/example/msl/src/MSLDataDictionary.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
diff --git a/example/msl/src/RemsTelemetryInitializer.js b/example/msl/src/RemsTelemetryInitializer.js
index 9a9c4401c5..695f05d257 100644
--- a/example/msl/src/RemsTelemetryInitializer.js
+++ b/example/msl/src/RemsTelemetryInitializer.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
diff --git a/example/msl/src/RemsTelemetryModelProvider.js b/example/msl/src/RemsTelemetryModelProvider.js
index c3f6f45374..9fd54a06a9 100644
--- a/example/msl/src/RemsTelemetryModelProvider.js
+++ b/example/msl/src/RemsTelemetryModelProvider.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
diff --git a/example/msl/src/RemsTelemetryProvider.js b/example/msl/src/RemsTelemetryProvider.js
index 3b32914e98..80c6b850c0 100644
--- a/example/msl/src/RemsTelemetryProvider.js
+++ b/example/msl/src/RemsTelemetryProvider.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
diff --git a/example/msl/src/RemsTelemetrySeries.js b/example/msl/src/RemsTelemetrySeries.js
index 8ffa8a427f..75a13136ee 100644
--- a/example/msl/src/RemsTelemetrySeries.js
+++ b/example/msl/src/RemsTelemetrySeries.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
diff --git a/example/msl/src/RemsTelemetryServerAdapter.js b/example/msl/src/RemsTelemetryServerAdapter.js
index 7ccb25f07d..a6b1858f4d 100644
--- a/example/msl/src/RemsTelemetryServerAdapter.js
+++ b/example/msl/src/RemsTelemetryServerAdapter.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
diff --git a/example/notifications/bundle.js b/example/notifications/bundle.js
index 28e15f1e34..93c66745e0 100644
--- a/example/notifications/bundle.js
+++ b/example/notifications/bundle.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
diff --git a/example/notifications/res/dialog-launch.html b/example/notifications/res/dialog-launch.html
index 9eebd2e3e5..c810f7f605 100644
--- a/example/notifications/res/dialog-launch.html
+++ b/example/notifications/res/dialog-launch.html
@@ -1,9 +1,9 @@
-
+
-
+
Known |
Unknown |
Error |
Info
- Dialogs
+
\ No newline at end of file
diff --git a/example/notifications/res/notification-launch.html b/example/notifications/res/notification-launch.html
index e5f5cbac6b..41aee23e63 100644
--- a/example/notifications/res/notification-launch.html
+++ b/example/notifications/res/notification-launch.html
@@ -1,9 +1,9 @@
-
+
-
+
Success |
Error |
Alert |
Progress
- Notifications
+
\ No newline at end of file
diff --git a/example/notifications/src/DialogLaunchController.js b/example/notifications/src/DialogLaunchController.js
index f35d008cd0..6e3e1271f0 100644
--- a/example/notifications/src/DialogLaunchController.js
+++ b/example/notifications/src/DialogLaunchController.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
@@ -44,30 +44,31 @@ define(
periodically with the progress of an ongoing process.
*/
$scope.launchProgress = function (knownProgress) {
- var model = {
- title: "Progress Dialog Example",
- progress: 0,
- hint: "Do not navigate away from this page or close this browser tab while this operation is in progress.",
- actionText: "Calculating...",
- unknownProgress: !knownProgress,
- unknownDuration: false,
- severity: "info",
- options: [
- {
- label: "Cancel Operation",
- callback: function () {
- $log.debug("Operation cancelled");
- dialogService.dismiss();
+ var dialog,
+ model = {
+ title: "Progress Dialog Example",
+ progress: 0,
+ hint: "Do not navigate away from this page or close this browser tab while this operation is in progress.",
+ actionText: "Calculating...",
+ unknownProgress: !knownProgress,
+ unknownDuration: false,
+ severity: "info",
+ options: [
+ {
+ label: "Cancel Operation",
+ callback: function () {
+ $log.debug("Operation cancelled");
+ dialog.dismiss();
+ }
+ },
+ {
+ label: "Do something else...",
+ callback: function () {
+ $log.debug("Something else pressed");
+ }
}
- },
- {
- label: "Do something else...",
- callback: function () {
- $log.debug("Something else pressed");
- }
- }
- ]
- };
+ ]
+ };
function incrementProgress() {
model.progress = Math.min(100, Math.floor(model.progress + Math.random() * 30));
@@ -77,7 +78,9 @@ define(
}
}
- if (dialogService.showBlockingMessage(model)) {
+ dialog = dialogService.showBlockingMessage(model);
+
+ if (dialog) {
//Do processing here
model.actionText = "Processing 100 objects...";
if (knownProgress) {
@@ -93,29 +96,31 @@ define(
Demonstrates launching an error dialog
*/
$scope.launchError = function () {
- var model = {
- title: "Error Dialog Example",
- actionText: "Something happened, and it was not good.",
- severity: "error",
- options: [
- {
- label: "Try Again",
- callback: function () {
- $log.debug("Try Again Pressed");
- dialogService.dismiss();
+ var dialog,
+ model = {
+ title: "Error Dialog Example",
+ actionText: "Something happened, and it was not good.",
+ severity: "error",
+ options: [
+ {
+ label: "Try Again",
+ callback: function () {
+ $log.debug("Try Again Pressed");
+ dialog.dismiss();
+ }
+ },
+ {
+ label: "Cancel",
+ callback: function () {
+ $log.debug("Cancel Pressed");
+ dialog.dismiss();
+ }
}
- },
- {
- label: "Cancel",
- callback: function () {
- $log.debug("Cancel Pressed");
- dialogService.dismiss();
- }
- }
- ]
- };
+ ]
+ };
+ dialog = dialogService.showBlockingMessage(model);
- if (!dialogService.showBlockingMessage(model)) {
+ if (!dialog) {
$log.error("Could not display modal dialog");
}
};
@@ -124,22 +129,25 @@ define(
Demonstrates launching an error dialog
*/
$scope.launchInfo = function () {
- var model = {
- title: "Info Dialog Example",
- actionText: "This is an example of a blocking info" +
- " dialog. This dialog can be used to draw the user's" +
- " attention to an event.",
- severity: "info",
- primaryOption: {
- label: "OK",
- callback: function () {
- $log.debug("OK Pressed");
- dialogService.dismiss();
+ var dialog,
+ model = {
+ title: "Info Dialog Example",
+ actionText: "This is an example of a blocking info" +
+ " dialog. This dialog can be used to draw the user's" +
+ " attention to an event.",
+ severity: "info",
+ primaryOption: {
+ label: "OK",
+ callback: function () {
+ $log.debug("OK Pressed");
+ dialog.dismiss();
+ }
}
- }
- };
+ };
- if (!dialogService.showBlockingMessage(model)) {
+ dialog = dialogService.showBlockingMessage(model);
+
+ if (!dialog) {
$log.error("Could not display modal dialog");
}
};
diff --git a/example/notifications/src/DialogLaunchIndicator.js b/example/notifications/src/DialogLaunchIndicator.js
index 9330ce2194..3d30e84be5 100644
--- a/example/notifications/src/DialogLaunchIndicator.js
+++ b/example/notifications/src/DialogLaunchIndicator.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
@@ -32,17 +32,15 @@ define(
* launched for demonstration and testing purposes.
* @constructor
*/
+
function DialogLaunchIndicator() {
}
DialogLaunchIndicator.template = 'dialogLaunchTemplate';
- DialogLaunchIndicator.prototype.getGlyph = function () {
- return "i";
- };
DialogLaunchIndicator.prototype.getGlyphClass = function () {
- return 'caution';
+ return 'ok';
};
DialogLaunchIndicator.prototype.getText = function () {
return "Launch test dialog";
diff --git a/example/notifications/src/NotificationLaunchController.js b/example/notifications/src/NotificationLaunchController.js
index 851e0575f5..20d3faf25d 100644
--- a/example/notifications/src/NotificationLaunchController.js
+++ b/example/notifications/src/NotificationLaunchController.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
diff --git a/example/notifications/src/NotificationLaunchIndicator.js b/example/notifications/src/NotificationLaunchIndicator.js
index 174810d721..b839fa81d6 100644
--- a/example/notifications/src/NotificationLaunchIndicator.js
+++ b/example/notifications/src/NotificationLaunchIndicator.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
@@ -26,17 +26,21 @@ define(
function () {
"use strict";
+ /**
+ * A tool for manually invoking notifications. When included this
+ * indicator will allow for notifications of different types to be
+ * launched for demonstration and testing purposes.
+ * @constructor
+ */
+
function NotificationLaunchIndicator() {
}
NotificationLaunchIndicator.template = 'notificationLaunchTemplate';
- NotificationLaunchIndicator.prototype.getGlyph = function () {
- return "i";
- };
NotificationLaunchIndicator.prototype.getGlyphClass = function () {
- return 'caution';
+ return 'ok';
};
NotificationLaunchIndicator.prototype.getText = function () {
return "Launch notification";
diff --git a/example/persistence/bundle.js b/example/persistence/bundle.js
index a728030c41..ae7dbca28c 100644
--- a/example/persistence/bundle.js
+++ b/example/persistence/bundle.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
diff --git a/example/persistence/src/BrowserPersistenceProvider.js b/example/persistence/src/BrowserPersistenceProvider.js
index e9f9440e29..2e1023c7dc 100644
--- a/example/persistence/src/BrowserPersistenceProvider.js
+++ b/example/persistence/src/BrowserPersistenceProvider.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
diff --git a/example/plotOptions/bundle.js b/example/plotOptions/bundle.js
index 4c234f5f7f..66a2e81937 100644
--- a/example/plotOptions/bundle.js
+++ b/example/plotOptions/bundle.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
@@ -81,7 +81,7 @@ define([
{
"key": "plot",
"name": "Example Telemetry Plot",
- "glyph": "\u0074",
+ "cssclass": "icon-telemetry-panel",
"description": "For development use. A plot for displaying telemetry.",
"priority": 10,
"delegates": [
diff --git a/example/policy/bundle.js b/example/policy/bundle.js
index 848248db0f..0da631d3a7 100644
--- a/example/policy/bundle.js
+++ b/example/policy/bundle.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
diff --git a/example/policy/src/ExamplePolicy.js b/example/policy/src/ExamplePolicy.js
index c19a038348..9429bc2306 100644
--- a/example/policy/src/ExamplePolicy.js
+++ b/example/policy/src/ExamplePolicy.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
diff --git a/example/profiling/bundle.js b/example/profiling/bundle.js
index 7473c9fdaf..49d0dd6fff 100644
--- a/example/profiling/bundle.js
+++ b/example/profiling/bundle.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
diff --git a/example/profiling/src/DigestIndicator.js b/example/profiling/src/DigestIndicator.js
index f19f28b548..826dd2f23f 100644
--- a/example/profiling/src/DigestIndicator.js
+++ b/example/profiling/src/DigestIndicator.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
@@ -59,11 +59,14 @@ define(
update();
return {
- getGlyph: function () {
- return ".";
- },
- getGlyphClass: function () {
- return undefined;
+ /**
+ * Get the CSS class that defines the icon
+ * to display in this indicator. This will appear
+ * as a dataflow icon.
+ * @returns {string} the cssclass of the dataflow icon
+ */
+ getCssClass: function () {
+ return "icon-connectivity";
},
getText: function () {
return displayed + " digests/sec";
diff --git a/example/scratchpad/bundle.js b/example/scratchpad/bundle.js
index 104d4adf65..141e2367b7 100644
--- a/example/scratchpad/bundle.js
+++ b/example/scratchpad/bundle.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
diff --git a/example/scratchpad/src/ScratchPersistenceProvider.js b/example/scratchpad/src/ScratchPersistenceProvider.js
index b45da31e5f..26b461185f 100644
--- a/example/scratchpad/src/ScratchPersistenceProvider.js
+++ b/example/scratchpad/src/ScratchPersistenceProvider.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
diff --git a/example/taxonomy/bundle.js b/example/taxonomy/bundle.js
index 4758db2ac2..897c078a96 100644
--- a/example/taxonomy/bundle.js
+++ b/example/taxonomy/bundle.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
diff --git a/example/taxonomy/src/ExampleTaxonomyModelProvider.js b/example/taxonomy/src/ExampleTaxonomyModelProvider.js
index d90e9bf941..f509150320 100644
--- a/example/taxonomy/src/ExampleTaxonomyModelProvider.js
+++ b/example/taxonomy/src/ExampleTaxonomyModelProvider.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
diff --git a/example/worker/bundle.js b/example/worker/bundle.js
index 7daf45f699..42b1e072f7 100644
--- a/example/worker/bundle.js
+++ b/example/worker/bundle.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
diff --git a/example/worker/src/FibonacciIndicator.js b/example/worker/src/FibonacciIndicator.js
index 77a55bc531..777fb3d2f5 100644
--- a/example/worker/src/FibonacciIndicator.js
+++ b/example/worker/src/FibonacciIndicator.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
@@ -50,15 +50,12 @@ define(
requestNext();
return {
- getGlyph: function () {
- return "?";
+ getCssClass: function () {
+ return "icon-object-unknown";
},
getText: function () {
return latest;
},
- getGlyphClass: function () {
- return "";
- },
getDescription: function () {
return "";
}
diff --git a/gulpfile.js b/gulpfile.js
index c3e82295d6..fab0f056e0 100644
--- a/gulpfile.js
+++ b/gulpfile.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
diff --git a/index.html b/index.html
index e16b096abb..e47efe91b5 100644
--- a/index.html
+++ b/index.html
@@ -1,9 +1,9 @@
-
# Open MCT Web Licenses
+
# Open MCT Licenses
## Apache License
diff --git a/platform/commonUI/about/res/templates/licenses.html b/platform/commonUI/about/res/templates/licenses.html
index 28c919198e..65466dbdc2 100644
--- a/platform/commonUI/about/res/templates/licenses.html
+++ b/platform/commonUI/about/res/templates/licenses.html
@@ -1,9 +1,9 @@
-
-
- {
diff --git a/platform/commonUI/browse/res/templates/browse-object.html b/platform/commonUI/browse/res/templates/browse-object.html
index 0524519ca4..996b34f312 100644
--- a/platform/commonUI/browse/res/templates/browse-object.html
+++ b/platform/commonUI/browse/res/templates/browse-object.html
@@ -1,9 +1,9 @@
-
{{type.getGlyph()}}
+
{{parameters.mode}}
{{model.name}}
diff --git a/platform/commonUI/browse/res/templates/browse/object-properties.html b/platform/commonUI/browse/res/templates/browse/object-properties.html
index ecce9fe60d..3d60997024 100644
--- a/platform/commonUI/browse/res/templates/browse/object-properties.html
+++ b/platform/commonUI/browse/res/templates/browse/object-properties.html
@@ -1,9 +1,9 @@
- v
+
\ No newline at end of file
diff --git a/platform/commonUI/browse/res/templates/view-object.html b/platform/commonUI/browse/res/templates/view-object.html
index e65e1387ca..c5fa669f13 100644
--- a/platform/commonUI/browse/res/templates/view-object.html
+++ b/platform/commonUI/browse/res/templates/view-object.html
@@ -1,9 +1,9 @@
{{ngModel.title}}
-
All fields marked * are required.
+
All fields marked are required.
-
OK
-
Cancel
diff --git a/platform/commonUI/dialog/res/templates/message.html b/platform/commonUI/dialog/res/templates/message.html
index 8568fe5fb1..6a2be98d99 100644
--- a/platform/commonUI/dialog/res/templates/message.html
+++ b/platform/commonUI/dialog/res/templates/message.html
@@ -16,11 +16,11 @@
diff --git a/example/profiling/src/WatchIndicator.js b/example/profiling/src/WatchIndicator.js
index 1fe8c649a4..1e9ef5e386 100644
--- a/example/profiling/src/WatchIndicator.js
+++ b/example/profiling/src/WatchIndicator.js
@@ -1,9 +1,9 @@
/*****************************************************************************
- * Open MCT Web, Copyright (c) 2014-2015, United States Government
+ * Open MCT, Copyright (c) 2014-2016, United States Government
* as represented by the Administrator of the National Aeronautics and Space
* Administration. All rights reserved.
*
- * Open MCT Web is licensed under the Apache License, Version 2.0 (the
+ * Open MCT is licensed under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
* License for the specific language governing permissions and limitations
* under the License.
*
- * Open MCT Web includes source code licensed under additional open source
+ * Open MCT includes source code licensed under additional open source
* licenses. See the Open Source Licenses file (LICENSES.md) included with
* this source code distribution or the Licensing information page available
* at runtime from the About dialog for additional information.
@@ -55,24 +55,13 @@ define(
return {
/**
* Get the glyph (single character used as an icon)
* to display in this indicator. This will return ".",
* which should appear as a dataflow icon.
* @returns {string} the character of the database icon
*/
- getGlyph: function () {
- return "E";
- },
- /**
- * Get the name of the CSS class to apply to the glyph.
- * This is used to color the glyph to match its
- * state (one of ok, caution or err)
- * @returns {string} the CSS class to apply to this glyph
- */
- getGlyphClass: function () {
- return (watches > 2000) ? "caution" :
- (watches < 1000) ? "ok" :
- undefined;
+ getCssClass: function () {
+ return "icon-database";
},
/**
* Get the text that should appear in the indicator.
@@ -55,24 +55,13 @@ define(
return {
/**
- * Get the glyph (single character used as an icon)
+ * Get the CSS class (single character used as an icon)
* to display in this indicator. This will return ".",
@@ -55,24 +55,13 @@ define(
* to display in this indicator. This will return ".",
- * which should appear as a dataflow icon.
+ * which should appear as a database icon.
* @returns {string} the character of the database icon
*/